﻿import React, { useState } from 'react';
import './WaterControls.css'; // Стили для кнопок

// Интерфейс для пропсов
interface WaterControlsProps {
    // Функция, которая будет вызываться при добавлении воды
    // Она принимает количество миллилитров как аргумент
    onAddWater: (amount: number) => void;
}

const WaterControls: React.FC<WaterControlsProps> = ({ onAddWater }) => {
    // Состояние для хранения значения в поле кастомного ввода
    const [customAmount, setCustomAmount] = useState<string>('');

    // Обработчик клика по кнопкам с предопределенным количеством
    const handlePresetClick = (amount: number) => {
        onAddWater(amount);
    };

    // Обработчик изменения в поле кастомного ввода
    const handleCustomChange = (event: React.ChangeEvent<HTMLInputElement>) => {
        // Позволяем вводить только цифры
        const value = event.target.value.replace(/[^0-9]/g, '');
        setCustomAmount(value);
    };

    // Обработчик клика по кнопке "Добавить" для кастомного значения
    const handleCustomSubmit = () => {
        const amount = parseInt(customAmount, 10);
        if (!isNaN(amount) && amount > 0) {
            onAddWater(amount);
            setCustomAmount(''); // Очищаем поле после добавления
        } else {
            console.warn("Пожалуйста, введите корректное число миллилитров");
            // Можно добавить уведомление для пользователя здесь
        }
    };

    // Обработчик нажатия Enter в поле ввода
    const handleKeyPress = (event: React.KeyboardEvent<HTMLInputElement>) => {
        if (event.key === 'Enter') {
            handleCustomSubmit();
        }
    }

    return (
        <div className="water-controls">
            <p className="controls-title">Сколько воды выпили?</p>
            <div className="preset-buttons">
                <button onClick={() => handlePresetClick(150)} title="Маленький стакан">💧 150 мл</button>
                <button onClick={() => handlePresetClick(250)} title="Стандартный стакан">💧 250 мл</button>
                <button onClick={() => handlePresetClick(500)} title="Бутылка">💧 500 мл</button>
                <button onClick={() => handlePresetClick(750)} title="Большая бутылка">💧 750 мл</button>
            </div>
            <div className="custom-input">
                <input
                    type="number" // Используем type="number", но также фильтруем ввод выше
                    value={customAmount}
                    onChange={handleCustomChange}
                    onKeyPress={handleKeyPress} // Добавляем обработчик Enter
                    placeholder="Или введите свое (мл)"
                    min="1" // Минимальное значение для валидации браузера
                />
                <button onClick={handleCustomSubmit}>Добавить</button>
            </div>
        </div>
    );
}

export default WaterControls;